@@ -6,7 +6,7 @@ Mojolicious::Plugin::Riotjs - A Mojolicious  plugin for including riot.js .tag f
 
 =head1 VERSION
 
-0.0201
+0.0203
 
 =head1 DESCRIPTION
 
@@ -90,7 +90,7 @@ L<npm|https://www.npmjs.com/>:
 use Mojo::Base 'Mojolicious::Plugin';
 use Cwd ();
 
-our $VERSION = '0.0201';
+our $VERSION = '0.0203';
 
 $ENV{NODE_PATH} ||= '';
 
@@ -111,9 +111,10 @@ C<NODE_PATH> if already set.
 
 sub node_paths {
   my ($self, $app) = @_;
+  my $node_modules = Cwd::abs_path('node_modules');
   my %PATH;
 
-  return grep { -d and !$PATH{$_}++ } split(/:/, $ENV{NODE_PATH}), Cwd::abs_path('node_modules'),
+  return grep { -d and !$PATH{$_}++ } split(/:/, $ENV{NODE_PATH}), $node_modules,
     $app->home->rel_dir('node_modules');
 }
 
